@@ -1,12 +1,16 @@
 import json
 import numbers
 
+from time import sleep
+
 from pyqldb.driver.qldb_driver import QldbDriver
 from amazon.ion.json_encoder import IonToJSONEncoder
 
 class QLDBDriver:
     def __init__(self, ledger):
         self.qldb_driver = QldbDriver(ledger_name = ledger)
+        self.TABLE_CREATION_POLL_PERIOD_SEC = 5
+        self.TABLE_DELETION_POLL_PERIOD_SEC = 5
     
     def to_collection(self, cursor):
         collection = []
@@ -28,6 +32,12 @@ class QLDBDriver:
         statement = f"CREATE TABLE {table_name}"
         self.qldb_driver.execute_lambda(lambda x: self.execute(x, statement))
 
+        while True:
+            sleep(self.TABLE_CREATION_POLL_PERIOD_SEC)
+
+            if self.table_exists(table_name):
+                break
+
         if primary_key is not None:
             statement = f"CREATE INDEX ON {table_name}({primary_key})"
             self.qldb_driver.execute_lambda(lambda x: self.execute(x, statement))
@@ -37,11 +47,20 @@ class QLDBDriver:
         statement = f"DROP TABLE {table_name}"
         self.qldb_driver.execute_lambda(lambda x: self.execute(x, statement))
 
+        while True:
+            sleep(self.TABLE_DELETION_POLL_PERIOD_SEC)
+
+            if not self.table_exists(table_name):
+                break
+
+
+
+    def table_exists(self, table_name):
+        return table_name in self.list_tables()
+
 
     def add_attribute(self, table_name, identifier, attribute_name, value = None):
-        tables = self.list_tables()
-
-        if not table_name in tables:
+        if not self.table_exists(table_name):
             raise Exception("Table not found!")
 
         if isinstance(value, str):
@@ -65,9 +84,7 @@ class QLDBDriver:
 
 
     def remove_attribute(self, table_name, identifier, attribute_name):
-        tables = self.list_tables()
-
-        if not table_name in tables:
+        if not self.table_exists(table_name):
             raise Exception("Table not found!")
 
         statement = f"SELECT {identifier} FROM {table_name}"
